@@ -2,7 +2,7 @@
    expr.c - limited shell-like expression parsing functions
    This file is part of the nss-pam-ldapd library.
 
-   Copyright (C) 2009, 2010 Arthur de Jong
+   Copyright (C) 2009, 2010, 2011 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -73,14 +73,14 @@ static const char *empty_expander(const char UNUSED(*name),void UNUSED(*expander
 /* definition of the parse functions (they call eachother) */
 MUST_USE static const char *parse_dollar_expression(
               const char *str,int *ptr,char *buffer,size_t buflen,
-              expander_t expander,void *expander_arg);
+              expr_expander_func expander,void *expander_arg);
 MUST_USE static const char *parse_expression(
               const char *str,int *ptr,int endat,char *buffer,size_t buflen,
-              expander_t expander,void *expander_arg);
+              expr_expander_func expander,void *expander_arg);
 
 MUST_USE static const char *parse_dollar_expression(
               const char *str,int *ptr,char *buffer,size_t buflen,
-              expander_t expander,void *expander_arg)
+              expr_expander_func expander,void *expander_arg)
 {
   char varname[MAXVARLENGTH];
   const char *varvalue;
@@ -93,6 +93,8 @@ MUST_USE static const char *parse_dollar_expression(
     if (parse_name(str,ptr,varname,sizeof(varname))==NULL)
       return NULL;
     varvalue=expander(varname,expander_arg);
+    if (varvalue==NULL)
+      varvalue="";
     if (str[*ptr]=='}')
     {
       /* simple substitute */
@@ -148,6 +150,8 @@ MUST_USE static const char *parse_dollar_expression(
     if (parse_name(str,ptr,varname,sizeof(varname))==NULL)
       return NULL;
     varvalue=expander(varname,expander_arg);
+    if (varvalue==NULL)
+      varvalue="";
     if (strlen(varvalue)>=buflen)
       return NULL;
     strcpy(buffer,varvalue);
@@ -157,7 +161,7 @@ MUST_USE static const char *parse_dollar_expression(
 
 MUST_USE static const char *parse_expression(
               const char *str,int *ptr,int endat,char *buffer,size_t buflen,
-              expander_t expander,void *expander_arg)
+              expr_expander_func expander,void *expander_arg)
 {
   int j=0;
   /* go over string */
@@ -190,7 +194,7 @@ MUST_USE static const char *parse_expression(
 }
 
 MUST_USE const char *expr_parse(const char *str,char *buffer,size_t buflen,
-                                expander_t expander,void *expander_arg)
+                                expr_expander_func expander,void *expander_arg)
 
 {
   int i=0;
@@ -221,6 +225,7 @@ SET *expr_vars(const char *str,SET *set)
         break;
       case '\\': /* escaped character, unescape */
         i++;
+        /* no break needed here */
       default: /* just skip */
         i++;
     }
