@@ -2,7 +2,7 @@
    attmap.h - attribute mapping variables
    This file is part of the nss-pam-ldapd library.
 
-   Copyright (C) 2007, 2008, 2009 Arthur de Jong
+   Copyright (C) 2007, 2008, 2009, 2010 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -20,8 +20,8 @@
    02110-1301 USA
 */
 
-#ifndef _ATTMAP_H
-#define _ATTMAP_H 1
+#ifndef NSLCD__ATTMAP_H
+#define NSLCD__ATTMAP_H 1
 
 #include "cfg.h"
 #include "myldap.h"
@@ -36,8 +36,7 @@ extern const char *attmap_group_cn;
 extern const char *attmap_group_userPassword;
 extern const char *attmap_group_gidNumber;
 extern const char *attmap_group_memberUid;
-extern const char *attmap_group_uniqueMember;
-/*extern const char *attmap_group_memberOf;*/
+extern const char *attmap_group_member;
 extern const char *attmap_host_cn;
 extern const char *attmap_host_ipHostNumber;
 extern const char *attmap_netgroup_cn;
@@ -45,7 +44,6 @@ extern const char *attmap_netgroup_nisNetgroupTriple;
 extern const char *attmap_netgroup_memberNisNetgroup;
 extern const char *attmap_network_cn;
 extern const char *attmap_network_ipNetworkNumber;
-/*extern const char *attmap_network_ipNetmaskNumber; */
 extern const char *attmap_passwd_uid;
 extern const char *attmap_passwd_userPassword;
 extern const char *attmap_passwd_uidNumber;
@@ -97,4 +95,4 @@ const char *attmap_get_value(MYLDAP_ENTRY *entry,const char *attr,char *buffer,s
    can either be an attribute or an attribute expression. */
 SET *attmap_add_attributes(SET *set,const char *attr);
 
-#endif /* not _ATTMAP_H */
+#endif /* not NSLCD__ATTMAP_H */
