@@ -49,6 +49,9 @@
 #include <nss.h>
 #endif /* HAVE_NSS_H */
 #include <pthread.h>
+#ifdef HAVE_PTHREAD_NP_H
+#include <pthread_np.h>
+#endif /* HAVE_PTHREAD_NP_H */
 #ifndef HAVE_GETOPT_LONG
 #include "compat/getopt_long.h"
 #endif /* not HAVE_GETOPT_LONG */
@@ -63,6 +66,7 @@
 #include "common.h"
 #include "compat/attrs.h"
 #include "compat/getpeercred.h"
+#include "compat/socket.h"
 
 /* buffer sizes for I/O */
 #define READBUFFER_MINSIZE 32
@@ -566,7 +570,7 @@ static void *worker(void UNUSED(*arg))
     if (j<0)
     {
       if (errno==EINTR)
-        log_log(LOG_DEBUG,"debug: select() failed (ignored): %s",strerror(errno));
+        log_log(LOG_DEBUG,"select() failed (ignored): %s",strerror(errno));
       else
         log_log(LOG_ERR,"select() failed: %s",strerror(errno));
       continue;
@@ -709,7 +713,7 @@ int main(int argc,char *argv[])
     exit(EXIT_FAILURE);
   }
   /* close all file descriptors (except stdin/out/err) */
-  i=sysconf(_SC_OPEN_MAX);
+  i=sysconf(_SC_OPEN_MAX)-1;
   /* if the system does not have OPEN_MAX just close the first 32 and
      hope we closed enough */
   if (i<0)
