@@ -19,7 +19,9 @@
 # 02110-1301 USA
 
 import logging
+import socket
 
+from ldap.filter import escape_filter_chars as escape
 import ldap
 
 import cfg
@@ -48,28 +50,27 @@ class PAMRequest(common.Request):
         in the DN if needed."""
         # check username for validity
         common.validate_name(parameters['username'])
-        # look up user DN if not known
-        if not parameters['userdn']:
-            entry = passwd.uid2entry(self.conn, parameters['username'])
-            if not entry:
-                raise ValueError('%r: user not found' % parameters['username'])
-            # save the DN
-            parameters['userdn'] = entry[0]
-            # get the "real" username
-            value = passwd.attmap.get_rdn_value(entry[0], 'uid')
-            if not value:
-                # get the username from the uid attribute
-                values = entry[1]['uid']
-                if not values or not values[0]:
-                    logging.warning('%s: is missing a %s attribute', dn, passwd.attmap['uid'])
-                value = values[0]
-            # check the username
-            if value and not common.isvalidname(value):
-                raise ValueError('%s: has invalid %s attribute', dn, passwd.attmap['uid'])
-            # check if the username is different and update it if needed
-            if value != parameters['username']:
-                logging.info('username changed from %r to %r', parameters['username'], value)
-                parameters['username'] = value
+        # look up user DN
+        entry = passwd.uid2entry(self.conn, parameters['username'])
+        if not entry:
+            raise ValueError('%r: user not found' % parameters['username'])
+        # save the DN
+        parameters['userdn'] = entry[0]
+        # get the "real" username
+        value = passwd.attmap.get_rdn_value(entry[0], 'uid')
+        if not value:
+            # get the username from the uid attribute
+            values = entry[1]['uid']
+            if not values or not values[0]:
+                logging.warning('%s: is missing a %s attribute', dn, passwd.attmap['uid'])
+            value = values[0]
+        # check the username
+        if value and not common.isvalidname(value):
+            raise ValueError('%s: has invalid %s attribute', dn, passwd.attmap['uid'])
+        # check if the username is different and update it if needed
+        if value != parameters['username']:
+            logging.info('username changed from %r to %r', parameters['username'], value)
+            parameters['username'] = value
 
 
 class PAMAuthenticationRequest(PAMRequest):
@@ -78,8 +79,8 @@ class PAMAuthenticationRequest(PAMRequest):
 
     def read_parameters(self, fp):
         return dict(username=fp.read_string(),
-                    userdn=fp.read_string(),
-                    servicename=fp.read_string(),
+                    ignore_userdn=fp.read_string(),
+                    service=fp.read_string(),
                     password=fp.read_string())
         #self.validate_request()
         # TODO: log call with parameters
@@ -87,7 +88,7 @@ class PAMAuthenticationRequest(PAMRequest):
     def write(self, parameters, code=constants.NSLCD_PAM_SUCCESS, msg=''):
         self.fp.write_int32(constants.NSLCD_RESULT_BEGIN)
         self.fp.write_string(parameters['username'])
-        self.fp.write_string(parameters['userdn'])
+        self.fp.write_string('')  # userdn
         self.fp.write_int32(code)  # authc
         self.fp.write_int32(constants.NSLCD_PAM_SUCCESS)  # authz
         self.fp.write_string(msg)  # authzmsg
@@ -123,11 +124,63 @@ class PAMAuthenticationRequest(PAMRequest):
             logging.debug('bind failed: %s', msg)
             self.write(parameters, constants.NSLCD_PAM_AUTH_ERR, msg)
 
-#class PAMAuthorisationRequest(PAMRequest):
 
-#    action = constants.NSLCD_ACTION_PAM_AUTHZ
+class PAMAuthorisationRequest(PAMRequest):
 
-#    def handle_request(self):
+    action = constants.NSLCD_ACTION_PAM_AUTHZ
+
+    def read_parameters(self, fp):
+        return dict(username=fp.read_string(),
+                    ignore_userdn=fp.read_string(),
+                    service=fp.read_string(),
+                    ruser=fp.read_string(),
+                    rhost=fp.read_string(),
+                    tty=fp.read_string())
+        # TODO: log call with parameters
+
+    def write(self, parameters, code=constants.NSLCD_PAM_SUCCESS, msg=''):
+        self.fp.write_int32(constants.NSLCD_RESULT_BEGIN)
+        self.fp.write_string(parameters['username'])
+        self.fp.write_string('')  # userdn
+        self.fp.write_int32(code)
+        self.fp.write_string(msg)
+        self.fp.write_int32(constants.NSLCD_RESULT_END)
+
+    def check_authzsearch(self, parameters):
+        if not cfg.pam_authz_search:
+            return
+        # escape all parameters
+        variables = dict((k, escape(v)) for k, v in parameters.items())
+        variables.update(
+                hostname=escape(socket.gethostname()),
+                fqdn=escape(socket.getfqdn()),
+                dn=variables['userdn'],
+                uid=variables['username'],
+            )
+        # go over all authz searches
+        for x in cfg.pam_authz_search:
+            filter = x.value(variables)
+            logging.debug('trying pam_authz_search "%s"', filter)
+            search = common.Search(self.conn, filter=filter, attributes=('dn', ))
+            try:
+                dn, values = search.items().next()
+            except StopIteration:
+                logging.error('pam_authz_search "%s" found no matches', filter)
+                raise
+            logging.debug('pam_authz_search found "%s"', dn)
+
+    def handle_request(self, parameters):
+        # fill in any missing userdn, etc.
+        self.validate_request(parameters)
+        # check authorisation search
+        try:
+            self.check_authzsearch(parameters)
+        except StopIteration:
+            self.write(parameters, constants.NSLCD_PAM_PERM_DENIED,
+                       'LDAP authorisation check failed')
+            return
+        # all tests passed, return OK response
+        self.write(parameters)
 
 
 #NSLCD_ACTION_PAM_SESS_O
